package de.fhhannover.inform.trust.ifmapj.binding.dom;

import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

import org.w3c.dom.Document;

/**
 * A very basic implementation of the {@link XmlMarshalable} interface
 * which should be enough to create all the IF-MAP base elements.
 * 
 * @author aw
 *
 */
class BasicXmlMarshalableImpl implements XmlMarshalable {
	
	private final String mXmlElementName;
	
	private final String mXmlValue;
	
	private final XmlNamespace mXmlNamespace;
	
	private final Map<String, XmlAttribute> mXmlAttributes;
	
	private final Map<String, XmlNamespace> mXmlNsDeclarations;
	
	private final Collection<XmlMarshalable> mXmlChildren;
	
	private final Collection<Document> mXmlChildrenDoc;
	
	BasicXmlMarshalableImpl(String elName, XmlNamespace elNs, String elValue) {
		
		mXmlElementName = elName;
		mXmlNamespace = elNs;
		mXmlValue = elValue;
		
		mXmlAttributes = new HashMap<String, XmlAttribute>();
		mXmlNsDeclarations = new HashMap<String, XmlNamespace>();
		mXmlChildren = new LinkedList<XmlMarshalable>();
		mXmlChildrenDoc = new LinkedList<Document>();
	}

	@Override
	public String getXmlElementName() {
		return mXmlElementName;
	}

	@Override
	public Collection<XmlAttribute> getXmlAttributes() {
		return mXmlAttributes.values();
	}

	@Override
	public Collection<XmlMarshalable> getXmlChildren() {
		return mXmlChildren;
	}

	@Override
	public Collection<XmlNamespace> getXmlNamespaceDeclarations() {
		return mXmlNsDeclarations.values();
	}

	@Override
	public XmlNamespace getXmlNamespace() {
		return mXmlNamespace;
	}

	@Override
	public String getXmlElementValue() {
		return mXmlValue;
	}

	@Override
	public void addXmlChild(XmlMarshalable child) {
		if (child == null)
			throw new NullPointerException();
		
		mXmlChildren.add(child);
	}

	@Override
	public void addXmlNsDeclaration(XmlNamespace ns) {
		if (ns == null)
			throw new NullPointerException();
		mXmlNsDeclarations.put(ns.getPrefix(), ns);
	}
	
	@Override
	public void addXmlAttribute(XmlAttribute attr) {
		if (attr == null)
			throw new NullPointerException();
		mXmlAttributes.put(attr.getName(), attr);
	}

	@Override
	public void addXmlAttribute(String name, String value) {
		if (name == null || value == null)
			throw new NullPointerException();
		mXmlAttributes.put(name, new XmlAttribute(name, value));
	}

	@Override
	public void addXmlChildDoc(Document doc) {
		if (doc == null)
			throw new NullPointerException();
		mXmlChildrenDoc.add(doc);
	}

	@Override
	public Collection<Document> getXmlChildrenDoc() {
		return mXmlChildrenDoc;
	}

}
