package de.fhhannover.inform.trust.ifmapj.messages;

import java.util.Collection;

import util.Pair;

/**
 * Some requests may hold extra namespace declarations.
 * 
 * For example, the {@link SearchRequest} can hold a result-filter, as well a a
 * match-links-filter attribute. If the filter string uses namespaces, these
 * have to be declared at some point. This inteface offers methods to do so.
 * 
 * <b>Note:</b> There is no support for default namespaces at this point.
 * 
 * @author aw
 *
 */
public interface NamespaceDeclarationHolder {
	
	/**
	 * Declare a new namespace on this element.
	 * 
	 * @param prefix
	 * @param uri
	 * 
	 * @throws NullPointerException if either prefix or uri is null.
	 */
	public void addNamespaceDeclaration(String prefix, String uri);
	
	/**
	 * <b>Note:</b> The returned collection is unmodifiable.
	 * 
	 * @return the {@link Collection} of namespaces.
	 */
	public Collection<Pair<String, String>> getNamespaceDeclarations();
}
