package de.fhhannover.inform.trust.ifmapj.identifier;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;

import org.junit.Test;

/**
 * Trivial tests for {@link IpAddress} class.
 * 
 * @author ibente
 *
 */
public class IpAddressTest {

	public String ad = "de.fhhannover.inform.trust";
	public String value = "127.0.0.1";

	@Test
	public void testIpAddress() {
		IpAddress ip = new IpAddress();
		
		assertNotNull(ip);
		assertNull(ip.getAdministrativeDomain());
		assertNull(ip.getValue());
		assertNotNull(ip.getType());
		assertEquals(IpAddressType.IPv4, ip.getType());
		
		ip.setAdministrativeDomain(ad);
		ip.setValue(value);
		ip.setType(IpAddressType.IPv6);
		
		assertEquals(ad, ip.getAdministrativeDomain());
		assertEquals(value, ip.getValue());
		assertEquals(IpAddressType.IPv6, ip.getType());
	}

	@Test
	public void testIpAddressToString() {
		
		IpAddress ip = new IpAddress();
		
		assertEquals("ip{null, IPv4}", ip.toString());
		
		ip.setType(null);
		assertEquals("ip{null, null}", ip.toString());
		
		ip.setAdministrativeDomain("abc");
		assertEquals("ip{null, null, abc}", ip.toString());
		
		ip.setType(IpAddressType.IPv6);
		assertEquals("ip{null, IPv6, abc}", ip.toString());
		
		ip.setValue("i'll never remember how it looks like");
		assertEquals("ip{i'll never remember how it looks like, IPv6, abc}",
				ip.toString());

		/* this actually tests the super class */
		ip.setAdministrativeDomain("");
		assertEquals("ip{i'll never remember how it looks like, IPv6}",
				ip.toString());
		
		ip.setValue("192.168.0.1");
		ip.setType(IpAddressType.IPv4);
		ip.setAdministrativeDomain(null);
		assertEquals("ip{192.168.0.1, IPv4}", ip.toString());
	}
}
